@@ -7,7 +7,7 @@ use Module::Load;
 use Swagger2;
 use Swagger2::SchemaValidator;
 
-our $VERSION = '0.002';    # VERSION
+our $VERSION = '0.002_001';    # TRIAL VERSION
 
 
 sub DEBUG { !!$ENV{SWAGGER2_DEBUG} }
@@ -296,7 +296,7 @@ Dancer2::Plugin::Swagger2 - A Dancer2 plugin for creating routes from a Swagger2
 
 =head1 VERSION
 
-version 0.002
+version 0.002_001
 
 =head1 SYNOPSIS
 
@@ -340,6 +340,13 @@ Then on the terminal run:
 
 You'll find the example files displayed above in the distribution and repository.
 
+=head1 MIGRATING FROM DANCER1
+
+If you've been using Dancer1 before you might know L<Dancer::Plugin::Swagger>.
+Please note that that module's workflow is completely different! It is about
+creating the spec from the app. The module described in this text is about
+reading the spec and creating parts of the app for you.
+
 =head1 DEBUGGING
 
 To see some more debug messages on STDERR set environment variable C<SWAGGER2_DEBUG>
@@ -353,7 +360,7 @@ Import routes from Swagger file. Named arguments:
 
 =over
 
-=item C<url>: URL to passed to C<Swagger2> module
+=item C<url>: URL to passed to L<Swagger2> module
 
 =item C<controller_factory>: custom callback generator/finder that returns callbacks to routes
 
